==> style-o-matic-1.1.5.tgz: package/es/components/Badge/BadgeIcon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, setCorePropDefaults, getValidProps, ROLE } from "../../lib";

var BadgeIcon = (_temp = _class = function (_CoreComponent) {
  _inherits(BadgeIcon, _CoreComponent);

  function BadgeIcon() {
    _classCallCheck(this, BadgeIcon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  BadgeIcon.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      _extends({}, props, { role: "img" }),
      children
    );
  };

  return BadgeIcon;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "span",
  uirole: ROLE.ICON
}), _temp);


export default BadgeIcon;

==> style-o-matic-1.1.37.tgz: package/es/components/Badge/BadgeIcon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getCorePropDefaults, getValidProps, ROLE } from "../../lib";

var BadgeIcon = (_temp = _class = function (_CoreComponent) {
  _inherits(BadgeIcon, _CoreComponent);

  function BadgeIcon() {
    _classCallCheck(this, BadgeIcon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  BadgeIcon.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      _extends({}, props, { role: "img" }),
      children
    );
  };

  return BadgeIcon;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "span",
  uirole: ROLE.ICON
}), _temp);


export default BadgeIcon;
